@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+""" routing for API """
 from django.conf.urls import patterns, include, url
 from rest_framework import routers
 from shiori.api import views
@@ -11,5 +12,4 @@ router.register(r'bookmark_tags', views.BookmarkTagViewSet)
 router.register(r'feed_subscription', views.FeedSubscriptionViewSet)
 
 urlpatterns = patterns('shiori.api.views',
-                       url(r'^', include(router.urls)),
-                       )
+                       url(r'^', include(router.urls)),)
